@@ -303,7 +303,12 @@ edit(initstr, startln, count)
 		emsg_on_display = FALSE;		/* may remove error message now */
 
 		c = vgetc();
-		if (c == Ctrl('C'))
+
+		/*
+		 * Ignore got_int when CTRL-C was typed here.
+		 * Don't ignore it in :global, we really need to break then.
+		 */
+		if (c == Ctrl('C') && !global_busy)
 			got_int = FALSE;
 
 #ifdef RIGHTLEFT
@@ -353,6 +358,7 @@ edit(initstr, startln, count)
 					break;
 				default:
 					ctrl_x_mode = 0;
+					edit_submode = NULL;
 					break;
 			}
 			showmode();
@@ -523,7 +529,8 @@ edit(initstr, startln, count)
 			  case Ctrl('X'):		/* Enter ctrl-x mode */
 				/* We're not sure which ctrl-x mode it will be yet */
 				ctrl_x_mode = CTRL_X_NOT_DEFINED_YET;
-				MSG("^X mode (^E/^Y/^L/^]/^F/^I/^K/^D)");
+				edit_submode = (char_u *)"^X mode (^E/^Y/^L/^]/^F/^I/^K/^D)";
+				showmode();
 				break;
 #endif /* INSERT_EXPAND */
 
@@ -1565,7 +1572,7 @@ docomplete:
 										(p_ws || done_dir == BOTH_DIRECTIONS))
 				{
 					edit_submode_extra = e_patnotf;
-					edit_submode_highl = TRUE;
+					edit_submode_highl = 'e';
 				}
 				else if (curr_match != NULL && complete_direction == FORWARD &&
 											curr_match->next != NULL)
@@ -1655,12 +1662,12 @@ docomplete:
 					else if (tot == 0)
 					{
 						edit_submode_extra = e_patnotf;
-						edit_submode_highl = TRUE;
+						edit_submode_highl = 'e';
 					}
 				}
 
 				/* eat the ESC to avoid leaving insert mode */
-				if (got_int)
+				if (got_int && !global_busy)
 				{
 					(void)vgetc();
 					got_int = FALSE;
@@ -1679,7 +1686,7 @@ docomplete:
 					if (curr_match == NULL || curr_match->original)
 					{
 						edit_submode_extra = (char_u *)"Back at original";
-						edit_submode_highl = TRUE;
+						edit_submode_highl = 'w';
 					}
 					else if (first_match != NULL &&
 							first_match->next != NULL &&
@@ -1687,7 +1694,7 @@ docomplete:
 							 first_match->next->original))
 					{
 						edit_submode_extra = (char_u *)"(the only match)";
-						edit_submode_highl = FALSE;
+						edit_submode_highl = NUL;
 					}
 				}
 
@@ -1711,7 +1718,17 @@ docomplete:
 				}
 				if (edit_submode_extra != NULL)
 				{
-					showmode();
+					if (!p_smd)
+					{
+						if (edit_submode_highl)
+						{
+							set_highlight('r');		/* Highlight mode */
+							msg_highlight = TRUE;
+						}
+						msg(edit_submode_extra);
+					}
+					else
+						showmode();
 					edit_submode_extra = NULL;
 				}
 
@@ -2742,11 +2759,16 @@ insertchar(c, force_formatting, second_indent)
 	/*
 	 * If there's any pending input, grab up to INPUT_BUFLEN at once.
 	 * This speeds up normal text input considerably.
+	 * Don't do this when 'cindent' is set, because we might need to re-indent
+	 * at a ':', or any other character.
 	 */
 #define INPUT_BUFLEN 100
 	if (!ISSPECIAL(c) && vpeekc() != NUL && State != REPLACE
+#ifdef CINDENT
+											&& !curbuf->b_p_cin
+#endif
 #ifdef RIGHTLEFT
-																&& !p_ri
+											&& !p_ri
 #endif
 																		)
 	{
