@@ -50,6 +50,7 @@ static void gui_update_horiz_scrollbar __ARGS((void));
 gui_start()
 {
 	char_u	*old_term;
+	int		pid;
 
 	old_term = strsave(term_strings[KS_NAME]);
 	mch_setmouse(FALSE);					/* first switch mouse off */
@@ -73,9 +74,24 @@ gui_start()
 	 * Don't do this when Vim was started with "-f" or the 'f' flag is present
 	 * in 'guioptions'.
 	 */
-	if (gui.in_use && gui.dofork &&
-					  vim_strchr(p_guioptions, GO_FORG) == NULL && fork() > 0)
-		exit(0);
+	if (gui.in_use && gui.dofork && vim_strchr(p_guioptions, GO_FORG) == NULL)
+	{
+		pid = fork();
+		if (pid > 0)		/* parent */
+			exit(0);
+#if defined(HAVE_SETSID) || defined(HAVE_SETPGID)
+		/*
+		 * Change our process group.  On some systems/shells a CTRL-C in the
+		 * shell where Vim was started would otherwise kill gvim!
+		 */
+		if (pid == 0)		/* child */
+# if defined(HAVE_SETSID)
+			(void)setsid();
+# else
+			(void)setpgid(0, 0);
+# endif
+#endif
+	}
 }
 
 /*
@@ -939,9 +955,9 @@ gui_get_menu_index(menu, state)
  * according to whether the command is an "unmenu" command.
  */
 	static int
-gui_get_menu_cmd_modes(cmd, force, noremap, unmenu)
+gui_get_menu_cmd_modes(cmd, forceit, noremap, unmenu)
 	char_u	*cmd;
-	int		force;		/* Was there a "!" after the command? */
+	int		forceit;		/* Was there a "!" after the command? */
 	int		*noremap;
 	int		*unmenu;
 {
@@ -967,7 +983,7 @@ gui_get_menu_cmd_modes(cmd, force, noremap, unmenu)
 		modes |= MENU_CMDLINE_MODE;
 		cmd++;
 	}
-	else if (force)					/* menu!, noremenu! */
+	else if (forceit)					/* menu!, noremenu! */
 		modes |= MENU_INSERT_MODE | MENU_CMDLINE_MODE;
 	else							/* menu, noremenu */
 		modes |= MENU_NORMAL_MODE | MENU_VISUAL_MODE;
@@ -983,10 +999,10 @@ gui_get_menu_cmd_modes(cmd, force, noremap, unmenu)
  * Do the :menu commands.
  */
 	void
-gui_do_menu(cmd, arg, force)
+gui_do_menu(cmd, arg, forceit)
 	char_u	*cmd;
 	char_u	*arg;
-	int		force;
+	int		forceit;
 {
 	char_u	*menu_path;
 	int		modes;
@@ -995,7 +1011,7 @@ gui_do_menu(cmd, arg, force)
 	int		unmenu;
 	char_u	*map_buf;
 
-	modes = gui_get_menu_cmd_modes(cmd, force, &noremap, &unmenu);
+	modes = gui_get_menu_cmd_modes(cmd, forceit, &noremap, &unmenu);
 	menu_path = arg;
 	if (*menu_path == NUL)
 	{
@@ -1447,10 +1463,10 @@ static int		expand_modes = 0x0;
  * Work out what to complete when doing command line completion of menu names.
  */
 	char_u *
-gui_set_context_in_menu_cmd(cmd, arg, force)
+gui_set_context_in_menu_cmd(cmd, arg, forceit)
 	char_u	*cmd;
 	char_u	*arg;
-	int		force;
+	int		forceit;
 {
 	char_u	*after_dot;
 	char_u	*p;
@@ -1476,7 +1492,7 @@ gui_set_context_in_menu_cmd(cmd, arg, force)
 		 * With :menu though you might want to add a menu with the same name as
 		 * one in another mode, so match menus fom other modes too.
 		 */
-		expand_modes = gui_get_menu_cmd_modes(cmd, force, NULL, &unmenu);
+		expand_modes = gui_get_menu_cmd_modes(cmd, forceit, NULL, &unmenu);
 		if (!unmenu)
 			expand_modes = MENU_ALL_MODES;
 
@@ -1983,6 +1999,7 @@ gui_do_horiz_scroll()
 	int		i;
 	int		vcol;
 	int		ret_val = FALSE;
+	int		width;
 
 	/* no wrapping, no scrolling */
 	if (curwin->w_p_wrap)
@@ -1990,6 +2007,9 @@ gui_do_horiz_scroll()
 
 	curwin->w_leftcol = scrollbar_value;
 
+	width = Columns;
+	if (curwin->w_p_nu)		/* 8 characters of window used by line number */
+		width -= 8;
 	i = 0;
 	vcol = 0;
 	p = ml_get_curline();
@@ -2009,9 +2029,9 @@ gui_do_horiz_scroll()
 	}
 
 	while (p[i] && i <= curwin->w_cursor.col
-									&& vcol <= curwin->w_leftcol + Columns)
+									&& vcol <= curwin->w_leftcol + width)
 		vcol += chartabsize(p[i++], (colnr_t)vcol);
-	if (vcol > curwin->w_leftcol + Columns)
+	if (vcol > curwin->w_leftcol + width)
 	{
 		/*
 		 * Cursor is on a character that is at least partly off the right hand
