@@ -47,19 +47,21 @@
 #endif
 
 /* 
- * Some systems have the page size in statfs, some in stat
+ * Some systems have the page size in statfs.f_bsize, some in stat.st_blksize
  */
-#ifdef HAVE_SYS_STATFS_H
-# include <sys/statfs.h>
-# define STATFS statfs
-# define F_BSIZE f_bsize
-# ifdef MINT
-#  define fstatfs(fd, buf, len, nul) fstat((fd), (buf))
-# endif
-#else
+#ifdef HAVE_ST_BLKSIZE
 # define STATFS stat
 # define F_BSIZE st_blksize
 # define fstatfs(fd, buf, len, nul) fstat((fd), (buf))
+#else
+# ifdef HAVE_SYS_STATFS_H
+#  include <sys/statfs.h>
+#  define STATFS statfs
+#  define F_BSIZE f_bsize
+#  ifdef MINT				/* do we still need this? */
+#   define fstatfs(fd, buf, len, nul) fstat((fd), (buf))
+#  endif
+# endif
 #endif
 
 /*
@@ -130,7 +132,8 @@ mf_open(fname, trunc_file)
 	MEMFILE			*mfp;
 	int				i;
 	off_t			size;
-#ifdef UNIX
+#if defined(STATFS) && defined(UNIX) && !defined(__QNX__)
+# define USE_FSTATFS
 	struct STATFS 	stf;
 #endif
 
@@ -167,7 +170,7 @@ mf_open(fname, trunc_file)
 	}
 	mfp->mf_page_size = MEMFILE_PAGE_SIZE;
 
-#ifdef UNIX
+#ifdef USE_FSTATFS
 	/*
 	 * Try to set the page size equal to the block size of the device.
 	 * Speeds up I/O a lot.
@@ -1099,7 +1102,7 @@ mf_need_trans(mfp)
 	return (mfp->mf_fname != NULL && mfp->mf_neg_count > 0);
 }
 
-#if 1			/* included for beta release, TODO: remove later */
+#if 0			/* included for beta testing only */
 /*
  * print statistics for a memfile (for debugging)
  */
