@@ -3483,6 +3483,7 @@ get_c_indent()
 						 *            asdfasdf);
 						 *     here;
 						 */
+term_again:
 						l = ml_get_curline();
 						if (find_last_paren(l) &&
 								(trypos = find_match_paren(ind_maxparen,
@@ -3521,7 +3522,10 @@ get_c_indent()
 						if (*skipwhite(l) == '}' &&
 								   (trypos = find_start_brace(ind_maxcomment))
 															!= NULL) /* XXX */
+						{
 							curwin->w_cursor.lnum = trypos->lnum;
+							goto term_again;
+						}
 					}
 				}
 			}
